@@ -27,8 +27,7 @@
 #include <AppStreamQt/release.h>
 #include <appstream/AppStreamIntegration.h>
 
-#include "libdiscover_backend_debug.h"
-#include "pk-offline-private.h"
+#include "libdiscover_backend_packagekit_debug.h"
 
 using namespace std::chrono_literals;
 
@@ -42,10 +41,8 @@ PackageKitNotifier::PackageKitNotifier(QObject *parent)
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::updatesChanged, this, &PackageKitNotifier::recheckSystemUpdateNeeded);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::transactionListChanged, this, &PackageKitNotifier::transactionListChanged);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::restartScheduled, this, &PackageKitNotifier::nowNeedsReboot);
-    connect(PackageKit::Daemon::global()->offline(), &PackageKit::Offline::changed, this, [this] {
-        if (auto offline = PackageKit::Daemon::global()->offline(); offline->updateTriggered() || offline->upgradeTriggered())
-            nowNeedsReboot();
-    });
+    connect(PackageKit::Daemon::global()->offline(), &PackageKit::Offline::changed, this, &PackageKitNotifier::checkNeedsReboot);
+    QTimer::singleShot(100, this, &PackageKitNotifier::checkNeedsReboot);
 
     m_appdata->load();
 
@@ -63,8 +60,9 @@ PackageKitNotifier::PackageKitNotifier(QObject *parent)
             if (!ok || days == 0) {
                 regularCheck->setInterval(24h); // refresh at least once every day
                 regularCheck->start();
-                if (!value.isEmpty())
+                if (!value.isEmpty()) {
                     qWarning() << "couldn't understand value for timer:" << value;
+                }
             }
 
             // if the setting is not empty, refresh will be carried out by unattended-upgrade
@@ -81,15 +79,6 @@ PackageKitNotifier::PackageKitNotifier(QObject *parent)
     m_recheckTimer->setInterval(200);
     m_recheckTimer->setSingleShot(true);
     connect(m_recheckTimer, &QTimer::timeout, this, &PackageKitNotifier::recheckSystemUpdate);
-
-    QFileSystemWatcher *watcher = new QFileSystemWatcher(this);
-    watcher->addPath(QStringLiteral(PK_OFFLINE_ACTION_FILENAME));
-    connect(watcher, &QFileSystemWatcher::fileChanged, this, &PackageKitNotifier::nowNeedsReboot);
-
-    QTimer::singleShot(100, this, [this]() {
-        if (QFile::exists(QStringLiteral(PK_OFFLINE_ACTION_FILENAME)))
-            nowNeedsReboot();
-    });
 }
 
 PackageKitNotifier::~PackageKitNotifier()
@@ -98,25 +87,35 @@ PackageKitNotifier::~PackageKitNotifier()
 
 void PackageKitNotifier::checkOfflineUpdates()
 {
-    if (!QFile::exists(QStringLiteral(PK_OFFLINE_RESULTS_FILENAME))) {
+    auto offline = PackageKit::Daemon::global()->offline();
+    // <bool, QStringList, Transaction::Role, qint64, Transaction::Error, QString>
+    auto results = offline->getResults();
+    results.waitForFinished();
+
+    if (results.isError()) {
         return;
     }
-    qCDebug(LIBDISCOVER_BACKEND_LOG) << "found offline update results at " << PK_OFFLINE_RESULTS_FILENAME;
 
-    KDesktopFile file(QStringLiteral(PK_OFFLINE_RESULTS_FILENAME));
-    KConfigGroup group(&file, QStringLiteral(PK_OFFLINE_RESULTS_GROUP));
-
-    const bool success = group.readEntry("Success", false);
-    const QString packagesJoined = group.readEntry("Packages");
-    const auto packages = QStringView(packagesJoined).split(QLatin1Char(','));
     const bool isMobile = QByteArrayList{"1", "true"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE"));
-    const QString errorCode = group.readEntry("ErrorCode");
-    static QSet<QString> allowedAlreadyInstalled = {
-        QStringLiteral("package-already-installed"),
-        QStringLiteral("all-packages-already-installed"),
+#if QPK_CHECK_VERSION(1, 1, 4)
+    const bool success = results.success();
+    const auto packages = results.packageIds();
+    const auto errorCode = results.error();
+#else
+    const bool success = results.argumentAt<0>();
+    const auto packages = results.argumentAt<1>();
+    const auto errorCode = qvariant_cast<PackageKit::Transaction::Error>(results.argumentAt(4));
+#endif
+    static QSet<PackageKit::Transaction::Error> allowedAlreadyInstalled = {
+        PackageKit::Transaction::ErrorPackageAlreadyInstalled,
+        PackageKit::Transaction::ErrorAllPackagesAlreadyInstalled,
     };
     if (!success && !allowedAlreadyInstalled.contains(errorCode)) {
-        const QString errorDetails = group.readEntry("ErrorDetails");
+#if QPK_CHECK_VERSION(1, 1, 4)
+        const QString errorDetails = results.errorDescription();
+#else
+        const QString errorDetails = results.argumentAt<5>();
+#endif
 
         auto *notification = new KNotification(QStringLiteral("OfflineUpdateFailed"), KNotification::Persistent);
         notification->setIconName(QStringLiteral("dialog-error"));
@@ -142,7 +141,11 @@ void PackageKitNotifier::checkOfflineUpdates()
             connect(trans, &PackageKit::Transaction::errorCode, this, [](PackageKit::Transaction::Error /*error*/, const QString &details) {
                 KNotification::event(QStringLiteral("OfflineUpdateRepairFailed"),
                                      i18n("Repair Failed"),
-                                     xi18nc("@info", "%1<nl/>Please report this error to your distribution.", details),
+                                     xi18nc("@info %1 is an error message and %3 is the name of the operating system",
+                                            "%1<nl/>Please <link url='%2'>report this error to %3</link>.",
+                                            details,
+                                            KOSRelease().bugReportUrl(),
+                                            KOSRelease().name()),
                                      KNotification::Persistent,
                                      QStringLiteral("discoverabstractnotifier"));
             });
@@ -158,13 +161,6 @@ void PackageKitNotifier::checkOfflineUpdates()
                                          QStringLiteral("discoverabstractnotifier"));
                 }
             });
-
-            // No matter what happened, clean up the results file if it still exists
-            // because at this point, there's nothing anyone can do with it
-            if (QFile::exists(QStringLiteral(PK_OFFLINE_RESULTS_FILENAME))) {
-                qCDebug(LIBDISCOVER_BACKEND_LOG) << "Removed offline results file";
-                PackageKit::Daemon::global()->offline()->clearResults();
-            }
         });
 
         notification->sendEvent();
@@ -185,7 +181,7 @@ void PackageKitNotifier::checkOfflineUpdates()
 
             notification->sendEvent();
         }
-        PackageKit::Daemon::global()->offline()->clearResults();
+        offline->clearResults();
     }
 }
 
@@ -199,8 +195,10 @@ void PackageKitNotifier::recheckSystemUpdateNeeded()
         first = false;
     }
 
-    if (auto offline = PackageKit::Daemon::global()->offline(); offline->updateTriggered() || offline->upgradeTriggered())
+    auto offline = PackageKit::Daemon::global()->offline();
+    if (offline->updateTriggered() || offline->upgradeTriggered()) {
         return;
+    }
 
     m_recheckTimer->start();
 }
@@ -214,7 +212,7 @@ void PackageKitNotifier::recheckSystemUpdate()
 
 void PackageKitNotifier::setupGetUpdatesTransaction(PackageKit::Transaction *trans)
 {
-    qCDebug(LIBDISCOVER_BACKEND_LOG) << "using..." << trans << trans->tid().path();
+    qCDebug(LIBDISCOVER_BACKEND_PACKAGEKIT_LOG) << "using..." << trans << trans->tid().path();
 
     trans->setProperty("normalUpdates", 0);
     trans->setProperty("securityUpdates", 0);
@@ -280,13 +278,13 @@ void PackageKitNotifier::checkDistroUpgrade()
 
 void PackageKitNotifier::refreshDatabase()
 {
-    if (auto offline = PackageKit::Daemon::global()->offline();
-        offline->updatePrepared() || offline->upgradePrepared() || offline->updateTriggered() || offline->upgradeTriggered()) {
+    auto offline = PackageKit::Daemon::global()->offline();
+    if (offline->updatePrepared() || offline->upgradePrepared() || offline->updateTriggered() || offline->upgradeTriggered()) {
         return;
     }
 
-    for (const auto &t : m_transactions) {
-        auto role = t->role();
+    for (const auto transaction : std::as_const(m_transactions)) {
+        auto role = transaction->role();
         if (role == PackageKit::Transaction::RoleUpdatePackages || role == PackageKit::Transaction::RoleUpgradeSystem) {
             return;
         }
@@ -309,8 +307,9 @@ QProcess *PackageKitNotifier::checkAptVariable(const QString &aptconfig, const Q
     QProcess *process = new QProcess;
     process->start(aptconfig, {QStringLiteral("dump")});
     connect(process, &QProcess::finished, this, [func, process, varname](int code) {
-        if (code != 0)
+        if (code != 0) {
             return;
+        }
 
         QRegularExpression rx(QLatin1Char('^') + varname + QStringLiteral(" \"(.*?)\";?$"), QRegularExpression::CaseInsensitiveOption);
         QTextStream stream(process);
@@ -328,16 +327,19 @@ QProcess *PackageKitNotifier::checkAptVariable(const QString &aptconfig, const Q
     return process;
 }
 
-void PackageKitNotifier::transactionListChanged(const QStringList &tids)
+void PackageKitNotifier::transactionListChanged(const QStringList &transactionIDs)
 {
-    if (auto offline = PackageKit::Daemon::global()->offline(); offline->updateTriggered() || offline->upgradeTriggered())
+    auto offline = PackageKit::Daemon::global()->offline();
+    if (offline->updateTriggered() || offline->upgradeTriggered()) {
         return;
+    }
 
-    for (const auto &tid : tids) {
-        if (m_transactions.contains(tid))
+    for (const auto &transactionID : transactionIDs) {
+        if (m_transactions.contains(transactionID)) {
             continue;
+        }
 
-        auto t = new PackageKit::Transaction(QDBusObjectPath(tid));
+        auto t = new PackageKit::Transaction(QDBusObjectPath(transactionID));
 
         connect(t, &PackageKit::Transaction::roleChanged, this, [this, t]() {
             if (t->role() == PackageKit::Transaction::RoleGetUpdates) {
@@ -356,7 +358,15 @@ void PackageKitNotifier::transactionListChanged(const QStringList &tids)
             m_transactions.remove(t->tid().path());
             t->deleteLater();
         });
-        m_transactions.insert(tid, t);
+        m_transactions.insert(transactionID, t);
+    }
+}
+
+void PackageKitNotifier::checkNeedsReboot()
+{
+    auto offline = PackageKit::Daemon::global()->offline();
+    if (offline->triggerAction() != PackageKit::Offline::ActionUnset) {
+        nowNeedsReboot();
     }
 }
 
@@ -370,7 +380,10 @@ void PackageKitNotifier::nowNeedsReboot()
 
 void PackageKitNotifier::onRequireRestart(PackageKit::Transaction::Restart type, const QString &packageID)
 {
-    PackageKit::Transaction *t = qobject_cast<PackageKit::Transaction *>(sender());
-    t->setProperty("requireRestart", qMax<int>(t->property("requireRestart").toInt(), type));
-    qCDebug(LIBDISCOVER_BACKEND_LOG) << "RESTART" << type << "is required for package" << packageID;
+    auto transaction = qobject_cast<PackageKit::Transaction *>(sender());
+    transaction->setProperty("requireRestart", qMax<int>(transaction->property("requireRestart").toInt(), type));
+    qCDebug(LIBDISCOVER_BACKEND_PACKAGEKIT_LOG) << "RESTART" << QMetaEnum::fromType<PackageKit::Transaction::Restart>().valueToKey(type)
+                                                << "is required for package" << packageID;
 }
+
+#include "moc_PackageKitNotifier.cpp"
