@@ -174,7 +174,7 @@ void RpmOstreeBackend::refreshDeployments()
         if (deployment->isBooted()) {
             if (m_currentlyBootedDeployment) {
                 qCWarning(RPMOSTREE_LOG) << "We already have a booted deployment. This is a bug.";
-                passiveMessage(i18n("rpm-ostree: Multiple booted deployments found. Please file a bug."));
+                passiveMessage(i18n("rpm-ostree backend: Multiple booted deployments found. Please file a bug."));
                 return;
             }
             m_currentlyBootedDeployment = deployment;
@@ -186,7 +186,7 @@ void RpmOstreeBackend::refreshDeployments()
 
     if (!m_currentlyBootedDeployment) {
         qCWarning(RPMOSTREE_LOG) << "We have not found the booted deployment. This is a bug.";
-        passiveMessage(i18n("rpm-ostree: No booted deployment found. Please file a bug."));
+        passiveMessage(i18n("rpm-ostree backend: No booted deployment found. Please file a bug."));
         return;
     }
 
