@@ -336,7 +336,7 @@ void ResourcesProxyModel::setFilteredCategoryName(const QString &categoryName)
     }
 }
 
-void ResourcesProxyModel::setFiltersFromCategory(Category *category)
+void ResourcesProxyModel::setFiltersFromCategory(const std::shared_ptr<Category> &category)
 {
     if (m_filters.category != category) {
         m_filters.category = category;
@@ -350,7 +350,7 @@ void ResourcesProxyModel::fetchSubcategories()
     auto categories = kToSet(m_filters.category ? m_filters.category->subCategories() : CategoryModel::global()->rootCategories());
 
     const int count = rowCount();
-    QSet<Category *> done;
+    QSet<std::shared_ptr<Category>> done;
     for (int i = 0; i < count && !categories.isEmpty(); ++i) {
         const auto resource = m_displayedResources[i].resource;
         const auto found = resource->categoryObjects(kSetToVector(categories));
@@ -358,8 +358,8 @@ void ResourcesProxyModel::fetchSubcategories()
         categories.subtract(found);
     }
 
-    const QVariantList ret = kTransform<QVariantList>(done, [](Category *category) {
-        return QVariant::fromValue<QObject *>(category);
+    const QVariantList ret = kTransform<QVariantList>(done, [](const std::shared_ptr<Category> &category) {
+        return QVariant::fromValue<std::shared_ptr<Category>>(category);
     });
     if (m_subcategories != ret) {
         m_subcategories = ret;
@@ -442,7 +442,7 @@ bool ResourcesProxyModel::orderedLessThan(const StreamResult &left, const Stream
     return false;
 }
 
-Category *ResourcesProxyModel::filteredCategory() const
+std::shared_ptr<Category> ResourcesProxyModel::filteredCategory() const
 {
     return m_filters.category;
 }
@@ -543,6 +543,17 @@ QVariant ResourcesProxyModel::data(const QModelIndex &index, int role) const
     return roleToValue(result, role);
 }
 
+QHash<int, int> ResourcesProxyModel::createRoleToProperty()
+{
+    QHash<int, int> ret;
+    static const QMetaObject *m = &AbstractResource::staticMetaObject;
+    for (const auto &[role, roleText] : ResourcesProxyModel::s_roles.asKeyValueRange()) {
+        int propidx = roleText.isEmpty() ? -1 : m->indexOfProperty(roleText.constData());
+        ret.insert(role, propidx);
+    }
+    return ret;
+}
+
 QVariant ResourcesProxyModel::roleToValue(const StreamResult &result, int role) const
 {
     const auto resource = result.resource;
@@ -589,19 +600,13 @@ QVariant ResourcesProxyModel::roleToValue(const StreamResult &result, int role)
     case Qt::ToolTipRole:
         return {};
     default: {
-        QByteArray roleText = roleNames().value(role);
-        if (Q_UNLIKELY(roleText.isEmpty())) {
-            qCDebug(LIBDISCOVER_LOG) << "unsupported role" << role;
-            return {};
-        }
-        static const QMetaObject *m = &AbstractResource::staticMetaObject;
-        int propidx = roleText.isEmpty() ? -1 : m->indexOfProperty(roleText.constData());
-
+        static QHash<int, int> s_roleToProperty = createRoleToProperty();
+        const int propidx = s_roleToProperty[role];
         if (Q_UNLIKELY(propidx < 0)) {
-            qCWarning(LIBDISCOVER_LOG) << "unknown role:" << role << roleText;
+            qCWarning(LIBDISCOVER_LOG) << "unknown role:" << role << roleNames()[role];
             return {};
         } else {
-            return m->property(propidx).read(resource);
+            return AbstractResource::staticMetaObject.property(propidx).read(resource);
         }
     }
     }
