@@ -144,14 +144,16 @@ void ResourcesUpdatesModel::init()
             connect(updater, &AbstractBackendUpdater::needsRebootChanged, this, &ResourcesUpdatesModel::needsRebootChanged);
             connect(updater, &AbstractBackendUpdater::destroyed, this, &ResourcesUpdatesModel::updaterDestroyed);
             connect(updater, &AbstractBackendUpdater::errorMessageChanged, this, &ResourcesUpdatesModel::errorMessagesChanged);
+            connect(updater, &AbstractBackendUpdater::fetchingChanged, this, &ResourcesUpdatesModel::refreshFetching);
             m_updaters += updater;
 
             m_lastIsProgressing |= updater->isProgressing();
         }
     }
+    refreshFetching();
 
     // To enable from command line use:
-    // kwriteconfig5 --file discoverrc --group Software --key UseOfflineUpdates true
+    // kwriteconfig6 --file discoverrc --group Software --key UseOfflineUpdates true
     auto sharedConfig = KSharedConfig::openConfig();
     KConfigGroup group(sharedConfig, u"Software"_s);
     m_offlineUpdates = group.readEntry<bool>("UseOfflineUpdates", false);
@@ -163,9 +165,11 @@ void ResourcesUpdatesModel::init()
             return;
         }
 
-        if (m_offlineUpdates == group.readEntry<bool>("UseOfflineUpdates", false)) {
+        const bool offlineUpdates = group.readEntry<bool>("UseOfflineUpdates", false);
+        if (m_offlineUpdates == offlineUpdates) {
             return;
         }
+        m_offlineUpdates = offlineUpdates;
         Q_EMIT useUnattendedUpdatesChanged();
     });
 
@@ -224,9 +228,9 @@ void ResourcesUpdatesModel::updateAll()
             return;
         }
 
-        m_transaction = new UpdateTransaction(this, updaters);
-        m_transaction->setStatus(Transaction::SetupStatus);
-        setTransaction(m_transaction);
+        auto transaction = new UpdateTransaction(this, updaters);
+        transaction->setStatus(Transaction::SetupStatus);
+        setTransaction(transaction);
         TransactionModel::global()->addTransaction(m_transaction);
         for (AbstractBackendUpdater *upd : updaters) {
             QMetaObject::invokeMethod(upd, &AbstractBackendUpdater::start, Qt::QueuedConnection);
@@ -308,6 +312,14 @@ qint64 ResourcesUpdatesModel::secsToLastUpdate() const
 
 void ResourcesUpdatesModel::setTransaction(UpdateTransaction *transaction)
 {
+    if (m_transaction == transaction) {
+        return;
+    }
+
+    if (m_transaction) {
+        disconnect(m_transaction, &UpdateTransaction::finished, this, &ResourcesUpdatesModel::finished);
+        disconnect(m_transaction, &UpdateTransaction::finished, this, &ResourcesUpdatesModel::progressingChanged);
+    }
     m_transaction = transaction;
     connect(transaction, &UpdateTransaction::finished, this, &ResourcesUpdatesModel::finished);
     connect(transaction, &UpdateTransaction::finished, this, &ResourcesUpdatesModel::progressingChanged);
@@ -329,6 +341,27 @@ bool ResourcesUpdatesModel::needsReboot() const
     return false;
 }
 
+void ResourcesUpdatesModel::refreshFetching()
+{
+    bool fetching = false;
+    for (auto updater : std::as_const(m_updaters)) {
+        if (updater->isFetchingUpdates()) {
+            fetching = true;
+            break;
+        }
+    }
+    if (fetching == m_fetching) {
+        return;
+    }
+    m_fetching = fetching;
+    Q_EMIT fetchingChanged();
+}
+
+bool ResourcesUpdatesModel::isFetching() const
+{
+    return m_fetching;
+}
+
 bool ResourcesUpdatesModel::readyToReboot() const
 {
     return kContains(m_updaters, [](AbstractBackendUpdater *updater) {
@@ -341,11 +374,6 @@ bool ResourcesUpdatesModel::useUnattendedUpdates() const
     return m_offlineUpdates;
 }
 
-void ResourcesUpdatesModel::setOfflineUpdates(bool offline)
-{
-    m_offlineUpdates = offline;
-}
-
 QStringList ResourcesUpdatesModel::errorMessages() const
 {
     QStringList ret;
@@ -360,3 +388,4 @@ QStringList ResourcesUpdatesModel::errorMessages() const
 }
 
 #include "ResourcesUpdatesModel.moc"
+#include "moc_ResourcesUpdatesModel.cpp"
